summaryrefslogtreecommitdiffstats
path: root/src/kernel/tqobject.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/tqobject.cpp')
-rw-r--r--src/kernel/tqobject.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kernel/tqobject.cpp b/src/kernel/tqobject.cpp
index 3c0b0f3b..85c69f8b 100644
--- a/src/kernel/tqobject.cpp
+++ b/src/kernel/tqobject.cpp
@@ -388,7 +388,7 @@ TQMetaCallEvent::~TQMetaCallEvent()
Notice that the TQ_OBJECT macro is mandatory for any object that
implements signals, slots or properties. You also need to run the
- \link moc.html moc program (Meta Object Compiler) \endlink on the
+ \link tqmoc.html tqmoc program (Meta Object Compiler) \endlink on the
source file. We strongly recommend the use of this macro in \e all
subclasses of TQObject regardless of whether or not they actually
use signals, slots and properties, since failure to do so may lead
@@ -3219,7 +3219,7 @@ TQVariant TQObject::property( const char *name ) const
className(), name );
return v;
}
- TQObject* that = (TQObject*) this; // moc ensures constness for the tqt_property call
+ TQObject* that = (TQObject*) this; // tqmoc ensures constness for the tqt_property call
that->tqt_property( id, 1, &v );
return v;
}